from distutils.core import setup

setup(
      name = "dictsearch",
      version = "1.0",
      author = "Tommy Carpenter",
      author_email = "tommyjcarpenter@gmail.com",
      url = "https://github.com/tommyjcarpenter/dictsearch",
      description = "A tool for iterating dictionaries as trees and printing all leaf nodes at some path",
      license = "MIT License",
     )